diff --git a/module/VuFind/src/VuFind/Bootstrapper.php b/module/VuFind/src/VuFind/Bootstrapper.php
index 1f4e6063cbf5e241383350c18fe04ff8a5a5d62b..008b98d1f940409df01f4615bf192a148cea7574 100644
--- a/module/VuFind/src/VuFind/Bootstrapper.php
+++ b/module/VuFind/src/VuFind/Bootstrapper.php
@@ -155,10 +155,9 @@ class Bootstrapper
      */
     protected function initSystemStatus()
     {
-        // If the system is unavailable, forward to a different place:
-        if (isset($this->config->System->available)
-            && !$this->config->System->available
-        ) {
+        // If the system is unavailable and we're not in the console, forward to the
+        // unavailable page.
+        if (!Console::isConsole() && !($this->config->System->available ?? true)) {
             $callback = function ($e) {
                 $routeMatch = new RouteMatch(
                     ['controller' => 'Error', 'action' => 'Unavailable'], 1